[**Empezar**](./empezar.md) > **Uso** > **Línea de comandos** _(actual)_

---

### Usar PDFMathTranslate mediante la línea de comandos

#### Uso básico

Después de la instalación, ingrese este comando para traducir su PDF.

```bash
pdf2zh_next document.pdf
```

> [!NOTE]
> 
> Si tu ruta contiene espacios, por favor enciérrala entre comillas.
> 
> ```bash
> pdf2zh_next "path with spaces/document.pdf"
> ```

Después de ejecutar la traducción, los archivos se generan en el **directorio de trabajo actual**.

> [!TIP]
> **¿Dónde está mi "Directorio de trabajo actual"?**
> Antes de ingresar un comando en la terminal, es posible que veas una ruta mostrada en tu terminal:
> 
> ```powershell
> PS C:\Users\XXX>
> ```
> 
> Este directorio es el "*Directorio de trabajo actual*."
> 
> Si no hay una ruta, intenta ejecutar este comando en la terminal:
> 
> ```bash
> pwd
> ```
> 
> Después de ejecutar este comando, se mostrará una ruta. Esta ruta es el "**Directorio de trabajo actual**". Los archivos traducidos aparecerán aquí.

---

#### Opciones avanzadas

Para explicaciones detalladas de parámetros adicionales de la línea de comandos, consulta [opciones avanzadas](./../advanced/advanced.md).

<div align="right"> 
<h6><small>Parte del contenido de esta página ha sido traducido por GPT y puede contener errores.</small></h6>